![Project logo](https://icongr.am/devicon/python-original.svg?size=128&color=currentColor)
# Welcome to PythonProject
It's a template for python projects.

## Installation

    python setup.py install
        
## Usage

### Quickstart

=> TODO

## License
:scales: :unlock: [MIT license](about/license)